Learn R Programming

hglm (version 1.2-8)

hglm-package: Hierarchical Generalized Linear Models

Description

The hglm package is used to fit hierarchical generalized linear models. It can be used for linear mixed models and generalized linear models with random effects for a variety of links and a variety of distributions for both the outcomes and the random effects. Fixed effects can also be fitted in the dispersion part of the model. The function can be called either by specifying the design matrices or as a formula. Currently, only the extended quasi likelihood (EQL; Lee et al., 2006) estimation method is available which is also the REML for linear mixed models.

Arguments

Details

ll{ Package: hglm Type: Package Version: 1.2-8 Date: 2013-05-08 Discussion: https://r-forge.r-project.org/forum/?group_id=558 BugReports: https://r-forge.r-project.org/tracker/?group_id=558 License: GPL (>= 2) LazyLoad: yes Depends: R (>= 2.10), utils, Matrix, MASS, dglm } This is version 1.2-7 of the hglm package.

References

Ronnegard, Lars, Xia Shen and Moudud Alam (2010). hglm: A Package for Fitting Hierarchical Generalized Linear Models. The R Journal, 2(2), 20-28. Lee, Youngjo, John A Nelder and Yudi Pawitan (2006) Generalized Linear Models with Random Effect: a unified analysis via h-likelihood. Chapman and Hall/CRC. Shen, Xia, Moudud Alam, Freddy Fikse and Lars Ronnegard (2013). A novel generalized ridge regression method for quantitative genetics. Genetics.

See Also

hglm, hglm2, plot.hglm