Extracts log-likelihood values from an existing hglm object hglm.obj.
Usage
"logLik"(object, REML=NULL, ...)
Arguments
object
A fitted hglm object.
REML
The default NULL returns all computed log-likelihoods. The option REML=TRUE returns only the adjusted profile log-likelihood profiled over fixed and random effects.
...
This argument is not used.
Value
A list of log-likelihood values for model selection purposes, where $hlik is the log-h-likelihood, $pvh the adjusted profile log-likelihood profiled over random effects, $pbvh the adjusted profile log-likelihood profiled over fixed and random effects, and $cAIC the conditional AIC.
Details
The use of log-likelihoods and cAIC is described in Lee, Nelder and Pawitan (2006).
References
Youngjo Lee, John A Nelder and Yudi Pawitan (2006) Generalized Linear Models with Random Effect: a unified analysis via h-likelihood. Chapman and Hall/CRC.