Learn R Programming

hglm (version 2.0-2)

hglm-package: Hierarchical Generalized Linear Models

Description

The hglm package is used to fit hierarchical generalized linear models. It can be used for linear mixed models and generalized linear models with random effects for a variety of links and a variety of distributions for both the outcomes and the random effects. Fixed effects can also be fitted in the dispersion part of the model. The function can be called either by specifying the design matrices or as a formula. The default estimation method is extended quasi likelihood (EQL; Lee et al., 2006) but from version 2.0 the HL11 correction has been implemented as well.

Arguments

Details

ll{ Package: hglm Type: Package Version: 2.0-2 Date: 2014-01-01 Discussion: https://r-forge.r-project.org/forum/?group_id=558 BugReports: https://r-forge.r-project.org/tracker/?group_id=558 License: GPL (>= 2) LazyLoad: yes Depends: R (>= 2.10), utils, Matrix, MASS } This is version 2.0-2 of the hglm package.

References

Lars Ronnegard, Xia Shen and Moudud Alam (2010). hglm: A Package for Fitting Hierarchical Generalized Linear Models. The R Journal, 2(2), 20-28. Youngjo Lee, John A Nelder and Yudi Pawitan (2006) Generalized Linear Models with Random Effect: a unified analysis via h-likelihood. Chapman and Hall/CRC. Xia Shen, Moudud Alam, Freddy Fikse and Lars Ronnegard (2013). A novel generalized ridge regression method for quantitative genetics. Genetics. Moudud Alam, Lars Ronnegard, Xia Shen (2014). Fitting spatial models in hglm. Submitted.

See Also

hglm, hglm2, plot.hglm